#
# spec file for package direnv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gopackagepath github.com/direnv/direnv
Name:           direnv
Version:        2.35.0
Release:        1.3
Summary:        Environment switcher for shells
License:        MIT
Group:          Productivity/File utilities
URL:            https://direnv.net/
Source0:        https://github.com/direnv/direnv/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Patch0:         resolve-bin-path.patch
BuildRequires:  fish
BuildRequires:  go >= 1.6
BuildRequires:  make
BuildRequires:  zstd

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%description
direnv knows how to hook into bash, zsh, tcsh and fish shell to load
or unload environment variables depending on the current directory.
This allows to have project-specific environment variables and not
clutter the "~/.profile" file.

%prep
%autosetup -a1 -p1

%build
%make_build PREFIX=%{_prefix} \
%ifnarch ppc64
  GO_BUILD_FLAGS="-buildmode=pie"
%endif

%install
%make_install PREFIX=%{_prefix}

export PATH="%{buildroot}%{_bindir}:${PATH}"
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions

direnv hook bash > %{buildroot}%{_sysconfdir}/bash_completion.d/direnv.sh
direnv hook fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
direnv hook zsh > %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%files
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-stdlib.1%{?ext_man}
%{_mandir}/man1/%{name}.toml.1%{?ext_man}
%{_mandir}/man1/%{name}-fetchurl.1%{?ext_man}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish
%{_datadir}/fish/vendor_conf.d/%{name}.fish

%files bash-completion
%dir %{_sysconfdir}/bash_completion.d
%{_sysconfdir}/bash_completion.d/direnv.sh

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Sun Dec 29 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 2.35.0:
  * doc: Add version requirement for load_dotenv option (#1326)
  * doc: fix broken link (#1327)
  * doc: update elvish docs (#1305)
  * docs: change Guix link to its package search. (#1268)
  * feat: add opam support (#1298)
  * fix: add NuShell into list of supported shells (#1260)
  * fix: close tmp file (#1272)
  * fix: direnv edit: use editor when EDITOR not found, closes #1246 (#1247)
  * fix: release script
  * fix: stdlib: enable flakes when use flake is used (#1299)
  * fix: stdlib: export GOBIN for layout_go (#1286)
  * fix: stdlib: update layout_python to resolve deprecation warning (#1176)
  * fix: using PWD in .env files (#1052)
  * test: Fix Murex python-layout test (#1293)
- create hook packages for fish, bash and zsh
- add resolve-bin-path.patch to fix exe path inside buildroot
* Thu Apr 11 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 2.34.0:
  * doc: README.md, man pages: it's typos (#1230)
  * doc: add shell setup instructions for oh-my-zsh (#1070)
  * doc: added fetchurl manpage link to README.md
  * doc: document XDG_DATA_HOME (#1185)
  * doc: update installation.md for Gentoo (#1206)
  * feat: add Murex support (#1242)
  * feat: added systemd shell for export (#1126)
  * feat: allow to disable warn timeouts (#1209)
  * feat: hide env diff (#1223, #1234)
  * feat: made 'direnv export' non private (#1229)
  * fix: use_julia should not set LD_LIBRARY_PATH (#900)
  * fix: add missing deps for release in go.mod
  * fix: avoid use of regex in bash hook output (#1043)
  * fix: direnv.toml.1.md: add examples for $HOME expansion
  * fix: stdlib: use_flake: don't keep old generations around (#1089)
  * fix: stdlib: use_node: strip leading v from version (#1071)
  * fix: support Bash 5.1 array PROMPT_COMMAND (#1208)
  * fix: update stdlib.sh to avoid deprecation warning (#1221)
  * fix: update zsh syntax in internal/cmd/shell_zsh.go (#1075)
- compress vendor tarball with zst
* Sun Jan 28 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.33.0:
  * fixes and updates to documentation
  * feat: direnv status --json
  * feat: add PowerShell Support
  * feat: add mergify configuration
  * feat: add support for armv7l platform in install.sh
  * feat: add watch print command
  * feat: alias direnv disallow to deny
  * feat: stdlib: create CACHEDIR.TAG inside .direnv
  * fix: allowPath for LoadedRC
  * fix: don't prompt to allow if user explicitly denied
  * fix: man/direnv-stdlib: fix obsolete opam-env example
  * fix: print correct path in source_env log message
  * fix: quote tcsh $PATH, to avoid failure on whitespace
  * fix: remove redundant nil check in CommandsDispatch
  * fix: update nixpkgs and shellcheck
* Mon Jun 26 2023 Avindra Goolcharan <avindra@opensuse.org>
- update to 2.32.3:
  * fix: stat the already open rc file rather than another path based one on it (#1044)
  * fix: remove deprecated io/ioutil uses (#1042)
  * fix: spelling fixes (#1041)
  * fix: appease Go 1.19 gofmt (#1040)
  * fix: stdlib: use_guix: Switch to guix shell. (#1045)
  * fix: pass BASH_PATH to make, matches the nixpkgs derivation (#1006)
  * fix: stdlib/layout_python: exclude patchlevel from $python_version (#1033)
  * fix: incorrect escape sequences during Loads under git-bash (Windows) (#1085)
  * fix: skip some tests for IBM Z mainframe's z/OS operating system (#1094)
  * doc: add Windows installation with winget (#1096)
  * doc: link 12factor webpage for more clarity (#1095)
  * website: add Plausible analytics
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 2.32.2:
  * doc: Add stdlib's layout_pyenv to docs
  * doc: Fix broken link
  * doc: Minor typo fix
  * doc: `$XDG_CONFIG_HOME/direnv/direnv.toml` => add (typically
    ~/.config/direnv/direnv.toml)
  * doc: add quickenv to Related projects
  * feat: Update layout anaconda to accept a path to a yml file
  * feat: install.sh: can specify direnv version
  * fix: elvish: replace deprecated `except` with `catch`
  * fix: installer.sh: make direnv executable for all
  * fix: path escaping
  * fix: stdlib: only use ANSI escape on TTY
  * fix: test: remove mentions of DIRENV_MTIME
  * fix: test: use lowercase -d flag for base64 decoding of DIRENV_DIFF
* Thu Nov 24 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.32.1
  * Support custom VIRTUAL_ENV for layout_python
  * Add gha shell for GitHub Actions
  * allow conda environment names to be detected from environment.yml
  * source_up_if_exists: A strict_env compatible version of source_up
  * Expand ~/ in whitelist paths
  * Add "block" and "revoke" as aliases of the "deny" command
  * Add "permit" and "grant" as aliases of the "allow" command
* Sat May  7 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.31.0
  * Don't load .env files by default
  * Allow skipping .env autoload
  * stdlib: add `env_vars_required`
  * FIX: version: trim surrounding spaces
  * FIX: ignore .envrc and .env if they are not files
  * bump actions/setup-go from 2.1.4 to 2.1.5
- Update to version 2.30.0
  * Add automatic .env load
  * Resolve symlinks during direnv deny
  * stdlib: use_flake handle no layout dir (#861)
  * go mod update
- Update to version 2.29.0
  * stdlib: add use_flake function
  * Updated conditional for zsh hook to be more forgiving
  * Add -r flag for matching Git branches with a regexp
  * Enable syntax hilights to the quick demo code
  * Fixed extra quotes for lower alpha characters
  * Remove noisy warning about PS1 again
* Thu Apr 28 2022 Dirk Müller <dmueller@suse.com>
- use https homepage
- spec-cleaner
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.28.0
  * Update to go 1.16
  * tcsh: fix variable escaping
  * docs: improve the documentation
  * Fixed fish shell hook to work with eval
  * Fixed layout anaconda <env_name_or_prefix>
- Build with pie enabled if available
- Add _service for vendor package
* Sat Nov 21 2020 Julien Enselme <jujens@jujens.eu>
- update to 2.24.0
  * direnv_load: avoid leaking DIRENV_DUMP_FILE_PATH (#715)
  * Add strict_env and unstrict_env (#572)
  * stdlib: add use_vim to source local vimrc (#497)
  * stdlib: add source_env_if_exists (#714)
  * Wording (#713)
  * build(deps): bump actions/checkout from v2.3.3 to v2.3.4 (#709)
  * build(deps): bump cachix/install-nix-action from v11 to v12 (#710)
  * Fix XDG_CACHE_HOME path (#711)
  * rc: make file existence check more robust (#706)
* Sun Oct 25 2020 Julien Enselme <jujens@jujens.eu>
- update to 2.23.1:
  * fix: handle links on Mac when using `allow` (#696)
  * fix: use restored env in exec (#695)
  * stdlib: add basename and dirname from realpath (#693)
  * stdlib.sh: remove tabs
  * dist: compile all the binaries statically
- incule changes from 2.23.0
  * stdlib: add source_url function (#562)
  * direnv: add fetchurl command (#686)
  * shell: Update Elvish hook to replace deprecated `explode` (#685)
* Wed Aug 19 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.21.3:
  * Replace direnv expand_path with pure bash (#631)
  * Fix #594 - write error to fd 3 on Windows (#634)
  * Make direnv hook output work on Windows (#632)
  * Update hook.md to remove ">" typo in Fish instructions (#624)
  * stdlib: layout go adds layout dir to GOPATH (#622)
  * direnv-stdlib.1: add layout php (#619)
  * stdlib: add PATH_rm [ ...] (#615)
  * Error handling tuples (#610)
  * Merge pull request #607 from punitagrawal/master
  * test: elvish: Fix evaluation function
  * stdlib.sh: Re-write grep pattern to avoid shell escape
  * man: Escape '.' at the beginning of line to remove manpage warning
  * stdlib: fix direnv_config_dir usage (#601)
  * direnv version: improve error message (#599)
  * README: fix NixOS link in installation.md (#589)
  * stdlib: add direnv_apply_dump (#587)
  * Simplify direnv_load and make it work even when the command crashes. (#568)
  * docs: fix fish installation instruction
  * test: test for utf-8 compatibility
  * config: add [global] section
  * config: add strict_env option
  * config: fix warn_timeout parsing (#582)
  * Github action for releases
  * config: fix the configuration file selection
  * stdlib: fix shellcheck warnings
* Thu May  7 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.21.2
  + stdlib: revert the set -euo pipefail change. It was causing too many issues for users.
  + direnv allow: fix the allow migration by also creating the parent target directory.
  + stdlib: fix unused variable in use node
  + stdlib: fix unused variable in source_up
  + test: add stdlib test skeleton
  + add dist release utility
  + change where the allow files are being stored
  + direnv status: also show the config
  + direnv exec: improve the error message
  + warn if PS1 is being exported
  + handle SIGINT during export in bash
  + export: display the full RC path instead of a relative one
  + direnv exec: the DIR argument is always required (#493)
  + direnv_load can now handle stdout outputs
  + stdlib: add layout_julia
  + Handle failing pipenv on empty file and avoid an extra pipenv execution (#510)
  + fix source_env behaviour when the file doesn't exists (#487)
  + watch_file can now watch multiple files in a single invocation (#524)
  + layout_python: prefer venv over virtualenv. Do not export VIRUAL_ENV if $python_version is unavailable or a virtual environment does not exist/can't be created
  + Adds layout_pyenv (#505)
  + Fix source_up docs to explain that search starts in parent directory (#518)
  + fix path_add to not leak local variables
  + layout_pyenv: support multiple python versions (#525)
  + Add a direnv_version <version_at_least> command to check the direnv version.
  + dotenv: handle undefined variables
  + source files from .config/direnv/lib/*.sh
  + stdlib: set -euo pipefail
* Mon Feb  4 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Oct 15 2018 sean@suspend.net
- Update to 2.17.0
  + CHANGE: hook expands the direnv path.
  + CHANGE: stdlib: direnv_load: disallow watching in child (#368)
  + README: add OpenSUSE to the list of distros
  + Revert "Use_nix: unset IN_NIX_SHELL"
* Mon Feb 26 2018 idonmez@suse.com
- Update to 2.15.2
  + Add support for allow folder whitelist (#332)
  + TOML configuration file! (#332, #337)
  + Add support for go 1.10 (#339)
* Sun Jan 21 2018 jengelh@inai.de
- Avoid specific user context in summary.
* Sat Dec 23 2017 avindra@opensuse.org
- Update to 2.14.0
  + support for Pipenv layout
  + version: make public
  + edit: run the command through bash
- Includes fix from 2.13.3
  + fix loading issue on macOS
- Includes fixes from 2.13.2
  + edit: fix path escaping
  + stdlib: fix find_up
  + stdlib: use absolute path in source_up
  + go-dotenv: update to latest master to fix a parsing error
  + remove ruby as a build dependency
* Mon Oct 16 2017 aavindraa@gmail.com
- General packaging cleanups
  - Drop _service file in favor of Github archive url
  - Explicitly list man pages (without wildcard)
  - Lint with spec-cleaner
- Update to 2.13.1
  + FIX: stdlib: make direnv_layout_dir lazy (#298)
- Includes 2.13.0:
  + NEW: stdlib: configurable direnv_layout_dir
  + CHANGE: stdlib: source the direnvrc directly
  + FIX: permit empty NODE_VERSION_PREFIX variable
  + FIX: pwd: Don't use -P to remove symlinks (#295)
  + FIX: also reload when mtime goes back in time
  + FIX: Prevent $HOME path from being striked (#287)
  + BUILD: use the new dep tool to manage dependencies
  + BUILD: dotenv: move to vendor folder
- Includes 2.12.x:
  + stdlib layout_python: fixes on no arg
  + FIX: stdlib path_add(), see #278
  + FIX: install from source instructions
  + NEW: support multiple items in path_add and PATH_add (#276)
  + NEW: add a configurable DIRENV_WARN_TIMEOUT option (#273)
  + CHANGE: rewrite the dotenv parsing, now supports commented lines
  + CHANGE: pass additional args to virtualenv (#261)
  + FIX: stdlib watch_file(): escaping fix
  + FIX: only output color if $TERM is not dumb (#264)
  + FIX: the watch_file documentation
- Includes 2.11.x:
  + FIX: node version sorting (#255)
  + FIX: Typo in MANPATH_add always generates "PATH missing" error. (#256)
  + FIX: only deploy the go 1.8 version
  + NEW: stdlib.sh: introduce MANPATH_add (#248)
  + NEW: provide packages using the equinox service
  + CHANGE: test direnv with go 1.8 (#254)
  + FIX: Add warning about source_env/up
  + FIX: go-md2man install instruction
- Includes 2.10.0:
  + NEW: use guix (#242)
  + CHANGE: use go-md2man to generate the man pages
  + FIX: tcsh escaping (#241)
  + FIX: doc typos and rewords (#226)
- Includes 2.9.0:
  + NEW: use_nix() is now watching default.nix and shell.nix
  + NEW: Allow to fix the bash path at built time
  + FIX: Panic on direnv current with no argument
  + FIX: Permit empty NODE_VERSION_PREFIX variable
  + FIX: layout_python: fail properly when python is not found
* Thu Apr 28 2016 fcastelli@suse.com
- Initial package release 2.8.1
